package com.infonline.sample.activities.base;

import android.os.Bundle;
import android.support.annotation.NonNull;
import android.support.annotation.StringRes;
import android.support.design.widget.BottomNavigationView;
import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentStatePagerAdapter;
import android.support.v4.view.ViewPager;
import android.support.v7.app.AppCompatActivity;
import android.view.MenuItem;

import com.infonline.sample.App;
import com.infonline.sample.R;
import com.infonline.sample.fragments.HistoryFragment;
import com.infonline.sample.fragments.HomeFragment;
import com.infonline.sample.fragments.LogEventFragment;
import com.infonline.sample.helper.PrefHelper;
import com.infonline.sample.helper.Static;

import de.infonline.lib.IOLSession;

/**
 * Created by Dipl.-Ing. Mike Sebastian Drozd on 09.12.2017.
 * Copyright © 2017 RockAByte GmbH. All rights reserved.
 */

public abstract class BaseActivity extends AppCompatActivity {

    private static final String TAG = "BaseActivity";

    private ViewPager viewPager;
    private BottomNavigationView bottomNavigationView;

    private BottomNavigationView.OnNavigationItemSelectedListener mOnNavigationItemSelectedListener
            = new BottomNavigationView.OnNavigationItemSelectedListener() {

        @Override
        public boolean onNavigationItemSelected(@NonNull MenuItem item) {
            switch (item.getItemId()) {
                case R.id.navigation_home:
                    setToolbarTitle(R.string.bottom_nav_title_home);
                    viewPager.setCurrentItem(0, true);
                    return true;
                case R.id.navigation_log_event:
                    setToolbarTitle(R.string.bottom_nav_title_log_event);
                    viewPager.setCurrentItem(1, true);
                    return true;
                case R.id.navigation_history:
                    setToolbarTitle(R.string.bottom_nav_title_history);
                    viewPager.setCurrentItem(2, true);
                    return true;
            }
            return false;
        }
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_base);
        bottomNavigationView = findViewById(R.id.base_navigation);
        bottomNavigationView.setOnNavigationItemSelectedListener(mOnNavigationItemSelectedListener);

        viewPager = findViewById(R.id.base_view_pager);
        InfoLineAdapter infoLineAdapter = new InfoLineAdapter(getSupportFragmentManager());
        viewPager.setAdapter(infoLineAdapter);
        viewPager.addOnPageChangeListener(new ViewPager.OnPageChangeListener() {

            private MenuItem prevMenuItem;

            @Override
            public void onPageScrolled(int position, float positionOffset, int positionOffsetPixels) {
            }

            @Override
            public void onPageSelected(int position) {
                if (prevMenuItem != null) {
                    prevMenuItem.setChecked(false);
                } else {
                    bottomNavigationView.getMenu().getItem(0).setChecked(false);
                }

                bottomNavigationView.getMenu().getItem(position).setChecked(true);
                prevMenuItem = bottomNavigationView.getMenu().getItem(position);
                Static.hideKeyboard(BaseActivity.this);
            }

            @Override
            public void onPageScrollStateChanged(int state) {

            }
        });
        setToolbarTitle(R.string.bottom_nav_title_home);
    }

    @Override
    public void onBackPressed() {
        if (viewPager.getCurrentItem() == 0) {
            // If the user is currently looking at the first step, allow the system to handle the
            // Back button. This calls finish() on this activity and pops the back stack.
            IOLSession.getSessionForType(App.getCurrentSessionType()).terminateSession();
            PrefHelper.clearSettings(this);
            IOLSession.clearLogs();
            super.onBackPressed();
            overridePendingTransition(android.R.anim.fade_in, android.R.anim.fade_out);
        } else {
            // Otherwise, select the previous step.
            viewPager.setCurrentItem(viewPager.getCurrentItem() - 1);
        }
    }

    private class InfoLineAdapter extends FragmentStatePagerAdapter {

        private static final int NUM_PAGES = 3;

        InfoLineAdapter(FragmentManager fm) {
            super(fm);
        }

        @Override
        public Fragment getItem(int position) {
            switch (position) {
                case 0:
                    return new HomeFragment();
                case 1:
                    return new LogEventFragment();
                case 2:
                    return new HistoryFragment();
                default:
                    return new HomeFragment();
            }
        }

        @Override
        public int getCount() {
            return NUM_PAGES;
        }
    }

    private void setToolbarTitle(@StringRes int resTitle) {
        if (getSupportActionBar() != null) {
            getSupportActionBar().setTitle(getString(resTitle));
        }
    }
}
