/*
 * EventSpinnerAdapter.java
 * 
 * Copyright (c) 2017 RockAByte GmbH. All rights reserved.
 */
package com.infonline.sample.adapter;

import android.content.Context;
import android.graphics.Color;
import android.graphics.Typeface;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.CheckedTextView;

import com.infonline.sample.App;
import com.infonline.sample.R;
import com.infonline.sample.helper.EventHelper;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import org.json.JSONTokener;

import java.util.Comparator;

import de.infonline.lib.IOLSessionType;

public class EventSpinnerAdapter extends ArrayAdapter<String> {

    private final String contextString;

    public EventSpinnerAdapter(Context context) {
        super(context, R.layout.item_spinner);
        contextString = context.getString(R.string.private_event_ext);

        add(context.getString(R.string.fragment_log_event_spinner_first_item_select_event));
        try {
            JSONObject config = getConfigFromResource(context);
            JSONObject activeEvents = config.getJSONObject("configuration").getJSONObject("activeEvents");
            JSONArray eventNames = activeEvents.names();
            for (int i = 0; i < eventNames.length(); i++) {
                JSONArray eventStates = activeEvents.getJSONArray(eventNames.getString(i));
                for (int n = 0; n < eventStates.length(); n++) {
                    String eventName = eventNames.getString(i) + "." + eventStates.getString(n);
                    if (!EventHelper.isPublicEvent(eventNames.getString(i))) {
                        eventName += " " + contextString;
                    }
                    if (!eventName.startsWith("custom")) {
                        add(eventName);
                    }
                }
            }
        } catch (JSONException ignore) {
        }

        sort(new Comparator<String>() {
            @Override
            public int compare(String lhs, String rhs) {
                return lhs.compareTo(rhs);
            }
        });
    }

    @Override
    public View getDropDownView(int position, @Nullable View convertView, @NonNull ViewGroup parent) {
        View view = super.getDropDownView(position, convertView, parent);
        CheckedTextView tv = (CheckedTextView) view;
        int dimension = (int) parent.getResources().getDimension(R.dimen.activity_default_margin);
        tv.setPadding(dimension, dimension, 0, dimension);
        if (position == 0) {
            // Set the hint text color gray
            tv.setTextColor(Color.WHITE);
            tv.setBackgroundColor(parent.getContext().getResources().getColor(R.color.colorPrimary));
            tv.setTypeface(Typeface.DEFAULT_BOLD);
        } else {
            tv.setTextColor(Color.BLACK);
            tv.setBackgroundColor(Color.WHITE);
            tv.setTypeface(Typeface.DEFAULT);
        }

        if (isItemBlocked(tv.getText().toString())) {
            tv.setTextColor(parent.getContext().getResources().getColor(R.color.colorAccent));
            tv.setBackgroundColor(Color.GRAY);
            tv.setTypeface(Typeface.SANS_SERIF);
        }
        return view;
    }

    private static JSONObject getConfigFromResource(Context context) {
        try {
//            int configId = context.getResources().getIdentifier(context.getPackageName() + ":raw/" + "szm_infonline_lib_config", null, null);
            String jsonString = new java.util.Scanner(context.getResources().openRawResource(
                    App.getCurrentSessionType() == IOLSessionType.OEWA ?
                            de.infonline.lib.R.raw.oewa_infonline_lib_config :
                            de.infonline.lib.R.raw.szm_infonline_lib_config
            )).useDelimiter("\\A").next();
            return (JSONObject) new JSONTokener(jsonString).nextValue();
        } catch (Exception e) {
        }
        return null;
    }

    public boolean isItemBlocked(String item) {
        return item.contains(contextString);

    }

}