package com.infonline.sample.fragments;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import com.infonline.sample.R;

import java.util.List;

import de.infonline.lib.IOLSession;

/**
 * Created by Dipl.-Ing. Mike Sebastian Drozd on 09.12.2017.
 * Copyright © 2017 RockAByte GmbH. All rights reserved.
 */

public class HistoryFragment extends BaseFragment {

    private TextView tvLog;
    private AlertDialog deleteDialog;

    @Override
    int getLayoutID() {
        return R.layout.fragment_history;
    }

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setHasOptionsMenu(true);
        prepareDeleteDialog();
    }

    private void prepareDeleteDialog() {
        DialogInterface.OnClickListener dialogClickListener = new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                switch (which) {
                    case DialogInterface.BUTTON_POSITIVE:
                        IOLSession.clearLogs();
                        tvLog.setText(getString(R.string.fragment_history_toast_message_logs_empty));
                        Toast.makeText(getContext(), getString(R.string.fragment_history_toast_message_logs_clear), Toast.LENGTH_SHORT).show();
                        dialog.dismiss();
                        break;

                    case DialogInterface.BUTTON_NEGATIVE:
                        dialog.dismiss();
                        break;
                }
            }
        };

        AlertDialog.Builder builder = new AlertDialog.Builder(getContext());
        deleteDialog = builder.setMessage(getString(R.string.fragment_history_dialog_logs_clear_title))
                .setPositiveButton(getString(R.string.fragment_history_dialog_logs_clear_positive), dialogClickListener)
                .setNegativeButton(getString(R.string.fragment_history_dialog_logs_clear_negative), dialogClickListener)
                .create();
    }

    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            loadLogsIntoView();
        }
    }

    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.history_fragment_menu, menu);
        super.onCreateOptionsMenu(menu, inflater);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case R.id.menu_delete_history:
                deleteLogs();
                break;
            case R.id.menu_share_history:
                shareHistory();
                break;
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);
        tvLog = view.findViewById(R.id.history_tv_log);

    }

    @Override
    public void onResume() {
        super.onResume();
        loadLogsIntoView();
    }

    private void loadLogsIntoView() {
        if (!isAdded())
            return;

        if (tvLog != null) {
            List<String> mostRecentLogsWithLimit = IOLSession.mostRecentLogsWithLimit(0);
            StringBuilder s = new StringBuilder();
            for (int i = 0; i < mostRecentLogsWithLimit.size(); i++) {
                s.append(mostRecentLogsWithLimit.get(i)).append("\n");
            }
            String text = s.toString();
            tvLog.setText(text.isEmpty() ? getString(R.string.fragment_history_toast_message_logs_empty) : text);
        }
    }

    private void shareHistory() {
        Intent sendIntent = new Intent();
        sendIntent.setAction(Intent.ACTION_SEND);
        sendIntent.putExtra(Intent.EXTRA_TEXT, tvLog.getText());
        sendIntent.setType("text/plain");
        startActivity(sendIntent);
    }

    private void deleteLogs() {
        deleteDialog.show();
    }


}
