package com.infonline.sample.fragments;

import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.RadioButton;
import android.widget.RadioGroup;
import android.widget.TextView;
import android.widget.Toast;

import com.infonline.sample.App;
import com.infonline.sample.R;
import com.infonline.sample.activities.web.IOLWebViewActivity;
import com.infonline.sample.activities.web.ManualWebViewActivity;

import de.infonline.lib.IOLSession;
import de.infonline.lib.IOLSessionPrivacySetting;

/**
 * Created by Dipl.-Ing. Mike Sebastian Drozd on 09.12.2017.
 * Copyright © 2017 RockAByte GmbH. All rights reserved.
 */

public class HomeFragment extends BaseFragment {

    private static final String TAG = "HomeFragment";
    private TextView tvVersion;
    private TextView tvStatus;
    //    private SwitchCompat scOptOut;
    private Button btnHybridWebView;
    private Button btnManualWebView;
    private Button btnCrash;
    private Button btnSendLogs;
    private RadioGroup radioGroup;

    private IOLSessionPrivacySetting currentPrivacySetting = App.getCurrentPrivacySetting();
    private String configVersion;

    @Override
    int getLayoutID() {
        return R.layout.fragment_home;
    }

    @Override
    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        tvVersion = view.findViewById(R.id.home_tv_version);
        tvStatus = view.findViewById(R.id.home_tv_status);

        btnHybridWebView = view.findViewById(R.id.home_btn_open_hybrid_web_view);
        btnManualWebView = view.findViewById(R.id.home_btn_open_manual_web_view);

        btnCrash = view.findViewById(R.id.home_btn_crash);
        btnSendLogs = view.findViewById(R.id.home_btn_send_loged_events);

        radioGroup = view.findViewById(R.id.home_rg);


        final RadioButton rbAck = view.findViewById(R.id.home_rb_ack);
        final RadioButton rbLin = view.findViewById(R.id.home_rb_lin);
        final RadioButton rbPio = view.findViewById(R.id.home_rb_pio);
        final RadioButton rbOut = view.findViewById(R.id.home_rb_out);


        if (currentPrivacySetting == null) {
            radioGroup.check(R.id.home_rb_out);
            rbOut.setTextColor(getResources().getColor(R.color.colorWhite));
        } else {
            switch (currentPrivacySetting) {
                case ACK:
                    radioGroup.check(R.id.home_rb_ack);
                    rbAck.setTextColor(getResources().getColor(R.color.colorWhite));
                    break;
                case LIN:
                    radioGroup.check(R.id.home_rb_lin);
                    rbLin.setTextColor(getResources().getColor(R.color.colorWhite));
                    break;
                case PIO:
                    radioGroup.check(R.id.home_rb_pio);
                    rbPio.setTextColor(getResources().getColor(R.color.colorWhite));
                    break;
            }
        }
        radioGroup.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup group, int checkedPrivacySetting) {
                switch (checkedPrivacySetting) {
                    case R.id.home_rb_ack:
                        rbAck.setTextColor(getResources().getColor(R.color.colorWhite));
                        rbLin.setTextColor(getResources().getColor(R.color.colorPrimary));
                        rbPio.setTextColor(getResources().getColor(R.color.colorPrimary));
                        rbOut.setTextColor(getResources().getColor(R.color.colorPrimary));
                        Log.i(TAG, "Currently selected ack");
                        initSession(IOLSessionPrivacySetting.ACK);
                        break;
                    case R.id.home_rb_lin:
                        rbAck.setTextColor(getResources().getColor(R.color.colorPrimary));
                        rbLin.setTextColor(getResources().getColor(R.color.colorWhite));
                        rbPio.setTextColor(getResources().getColor(R.color.colorPrimary));
                        rbOut.setTextColor(getResources().getColor(R.color.colorPrimary));
                        Log.i(TAG, "Currently selected lin");
                        initSession(IOLSessionPrivacySetting.LIN);
                        break;
                    case R.id.home_rb_pio:
                        rbAck.setTextColor(getResources().getColor(R.color.colorPrimary));
                        rbLin.setTextColor(getResources().getColor(R.color.colorPrimary));
                        rbPio.setTextColor(getResources().getColor(R.color.colorWhite));
                        rbOut.setTextColor(getResources().getColor(R.color.colorPrimary));
                        Log.i(TAG, "Currently selected pio");
                        initSession(IOLSessionPrivacySetting.PIO);
                        break;
                    case R.id.home_rb_out:
                        rbAck.setTextColor(getResources().getColor(R.color.colorPrimary));
                        rbLin.setTextColor(getResources().getColor(R.color.colorPrimary));
                        rbPio.setTextColor(getResources().getColor(R.color.colorPrimary));
                        rbOut.setTextColor(getResources().getColor(R.color.colorWhite));
                        Log.i(TAG, "Currently selected out");
                        initSession(null);
                        break;
                }
            }
        });

        initActions();
    }


    @Override
    public void setUserVisibleHint(boolean isVisibleToUser) {
        super.setUserVisibleHint(isVisibleToUser);
        if (isVisibleToUser) {
            enableWebViewButtons(true);
            setupBasicInfo(currentPrivacySetting != null);
        }
    }


    @Override
    public void onResume() {
        super.onResume();
        enableWebViewButtons(true);
        setupBasicInfo(currentPrivacySetting != null);
    }

    private void initSession(IOLSessionPrivacySetting privacySetting) {
        IOLSession sessionForType = IOLSession.getSessionForType(App.getCurrentSessionType());

        if (privacySetting == null && sessionForType.isActive()) {
            sessionForType.terminateSession();
            App.clearPrivacySetting();
            setupBasicInfo(false);
            return;
        }


        if (privacySetting != null && !privacySetting.equals(App.getCurrentPrivacySetting())) {
            sessionForType.terminateSession();
            App application = (App) getActivity().getApplication();
            application.initIOLSessionType(App.getCurrentSessionType(), App.getCurrentUserInput(), privacySetting);
            setupBasicInfo(true);
        }
    }

    private void initActions() {

        btnCrash.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                throw new RuntimeException("This is a forced test crash!");
            }
        });

        btnSendLogs.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                IOLSession.getSessionForType(App.getCurrentSessionType()).sendLoggedEvents();
                Toast.makeText(getContext(), getString(R.string.fragment_home_toast_send_logs), Toast.LENGTH_SHORT).show();
            }
        });

        btnHybridWebView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(getContext(), IOLWebViewActivity.class);
                startActivity(intent);
                enableWebViewButtons(false);
            }
        });

        btnManualWebView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(getContext(), ManualWebViewActivity.class);
                startActivity(intent);
                enableWebViewButtons(false);
            }
        });

    }

    private void enableWebViewButtons(boolean enabled) {
        if (btnHybridWebView != null && btnManualWebView != null) {
            btnHybridWebView.setEnabled(enabled);
            btnManualWebView.setEnabled(enabled);
        }
    }


    private void setupBasicInfo(final boolean active) {
        if (!isAdded())
            return;

        IOLSession currentSession = App.getCurrentSession();
        String sessionType = App.getCurrentSessionType().state;
        configVersion = currentSession.getConfigVersion();


        if (active) {
            tvStatus.setText(getString(R.string.fragment_home_text_current_state, sessionType,
                    getString(R.string.fragment_home_text_current_state_active)));
            if (configVersion.contains("null")) {
                tvVersion.setText(getString(R.string.fragment_home_text_current_version, configVersion));
                currentSession.setConfigReadyCallback(new IOLSession.ConfigVersionCallback() {
                    @Override
                    public void onConfig(final String configVersion_) {
                        if (!HomeFragment.this.isAdded())
                            return;

                        getActivity().runOnUiThread(new Runnable() {
                            @Override
                            public void run() {
                                configVersion = configVersion_;
                                tvVersion.setText(getString(R.string.fragment_home_text_current_version, configVersion));
                            }
                        });
                    }
                });
            } else {
                tvVersion.setText(getString(R.string.fragment_home_text_current_version, configVersion));
            }
        } else {
            tvStatus.setText(getString(R.string.fragment_home_text_current_state, sessionType,
                    getString(R.string.fragment_home_text_current_state_inactive)));
            tvVersion.setText(getString(R.string.fragment_home_text_current_version_inactive));
        }
    }
}
