package com.infonline.sample.fragments;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.design.widget.TabLayout;
import android.util.Log;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.CheckedTextView;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import com.infonline.sample.App;
import com.infonline.sample.R;
import com.infonline.sample.adapter.EventSpinnerAdapter;
import com.infonline.sample.helper.EventHelper;
import com.infonline.sample.helper.Static;
import com.infonline.sample.widgets.KeyValueView;

import java.util.HashMap;
import java.util.Map;

import de.infonline.lib.IOLEvent;
import de.infonline.lib.IOLSession;

/**
 * Created by Dipl.-Ing. Mike Sebastian Drozd on 09.12.2017.
 * Copyright © 2017 RockAByte GmbH. All rights reserved.
 */

public class LogEventFragment extends BaseFragment implements TabLayout.OnTabSelectedListener {

    private final static String TAG = "LogEventFragment";
    private LinearLayout llCustomValues;
    private TextView tvAddCustomParameter;
    private Spinner spinnerParameter;
    private LinearLayout llBasicName;
    private EditText edtBasicCustomEventName;
    private KeyValueView kvvOptionalParameter;
    private TabLayout tabLayout;

    @Override
    int getLayoutID() {
        return R.layout.fragment_log_event;
    }

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setHasOptionsMenu(true);
    }

    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        inflater.inflate(R.menu.log_event_fragment_menu, menu);
        super.onCreateOptionsMenu(menu, inflater);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        switch (item.getItemId()) {
            case R.id.menu_log_event:
                sendLogs();
                break;
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        tabLayout = view.findViewById(R.id.log_event_tabs);
        tabLayout.addTab(tabLayout.newTab().setText(App.getCurrentSessionType().state));
        tabLayout.addTab(tabLayout.newTab().setText(R.string.fragment_log_event_tab_title_custom));
        tabLayout.setTabGravity(TabLayout.GRAVITY_FILL);
        tabLayout.addOnTabSelectedListener(this);

        llCustomValues = view.findViewById(R.id.log_event_ll_main_values);
        kvvOptionalParameter = view.findViewById(R.id.log_event_kv_optional_parameter);
        llBasicName = view.findViewById(R.id.log_event_ll_select_event_basic);
        edtBasicCustomEventName = view.findViewById(R.id.log_event_edt_select_event_basic);

        spinnerParameter = view.findViewById(R.id.log_event_spinner_select_event);
        final EventSpinnerAdapter spinnerAdapter = new EventSpinnerAdapter(getContext());
        spinnerAdapter.setDropDownViewResource(R.layout.item_spinner);
        spinnerParameter.setAdapter(spinnerAdapter);
        spinnerParameter.setSelection(0);
        spinnerParameter.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
            @Override
            public void onItemSelected(AdapterView<?> parentView, View selectedItemView, int position, long id) {
                if (selectedItemView != null) {
                    CheckedTextView tv = (CheckedTextView) selectedItemView;

                    if (spinnerAdapter.isItemBlocked(tv.getText().toString())) {
                        spinnerParameter.setSelection(0);
                    } else {
                        spinnerParameter.setSelection(position);
                    }
                }
            }

            @Override
            public void onNothingSelected(AdapterView<?> parentView) {
                // your code here
            }

        });

        tvAddCustomParameter = view.findViewById(R.id.log_event_tv_add_custom_parameter);
        tvAddCustomParameter.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                addCustomParameterToLayout();
            }
        });

        clearViews();
    }

    @Override
    public void onTabSelected(TabLayout.Tab tab) {
        Log.i(TAG, "CurrentTab: " + tab.getText());
        setCustomInput(tab.getText() != null && tab.getText().equals(getString(R.string.fragment_log_event_tab_title_custom)));
        tabLayout.requestFocus();
    }

    private void setCustomInput(boolean customInput) {
        if (customInput) {
            tvAddCustomParameter.setVisibility(View.VISIBLE);

            spinnerParameter.setVisibility(View.GONE);
            llBasicName.setVisibility(View.VISIBLE);
            edtBasicCustomEventName.setVisibility(View.VISIBLE);
        } else {
            tvAddCustomParameter.setVisibility(View.VISIBLE);

            spinnerParameter.setVisibility(View.VISIBLE);
            llBasicName.setVisibility(View.GONE);
            edtBasicCustomEventName.setVisibility(View.GONE);
        }
    }

    @Override
    public void onTabUnselected(TabLayout.Tab tab) {

    }

    @Override
    public void onTabReselected(TabLayout.Tab tab) {

    }

    private void clearOptionalParameter() {
        kvvOptionalParameter.setUpView(new KeyValueView.KeyValueViewModel(
                getString(R.string.fragment_log_event_optional_parameter_title),
                getString(R.string.fragment_log_event_optional_parameter_category),
                getString(R.string.fragment_log_event_optional_parameter_category_value),
                getString(R.string.fragment_log_event_optional_parameter_comment),
                getString(R.string.fragment_log_event_optional_parameter_comment_value)));
        kvvOptionalParameter.clearInput();
    }

    private void addCustomParameterToLayout() {
        KeyValueView.KeyValueViewModel keyValueViewModel = new KeyValueView.KeyValueViewModel(
                getString(R.string.fragment_log_event_custom_parameter_title),
                getString(R.string.fragment_log_event_custom_parameter_key_1),
                getString(R.string.fragment_log_event_custom_parameter_value_1),
                getString(R.string.fragment_log_event_custom_parameter_key_2),
                getString(R.string.fragment_log_event_custom_parameter_value_2));
        KeyValueView keyValueView = new KeyValueView(getContext(), keyValueViewModel);
        llCustomValues.addView(keyValueView);
    }


    private void clearViews() {
        llCustomValues.removeAllViews();
        setCustomInput(false);
        clearOptionalParameter();
        TabLayout.Tab tab = tabLayout.getTabAt(0);
        tab.select();
        edtBasicCustomEventName.setText("");
        spinnerParameter.setSelection(0);
    }


    private void sendLogs() {
        Map<String, String> customParams = null;
        String eventName = null;
        String customEventName = edtBasicCustomEventName.getText().toString();

        //Sending Spinner Selection with optional Parameters!
        String selectedItem = (String) spinnerParameter.getSelectedItem();

        int selectedTabPosition = tabLayout.getSelectedTabPosition();
        if (selectedTabPosition == 0 && !selectedItem.equals(getString(R.string.fragment_log_event_spinner_first_item_select_event))) {
            eventName = selectedItem;
        } else if (selectedTabPosition == 0 && selectedItem.equals(getString(R.string.fragment_log_event_spinner_first_item_select_event))) {
            Toast.makeText(getContext(), R.string.fragment_log_event_send_event_toast_error_event, Toast.LENGTH_SHORT).show();
            return;
        } else if (selectedTabPosition == 1 && !customEventName.isEmpty()) {
            eventName = "custom." + customEventName;
        } else if (selectedTabPosition == 1 && customEventName.isEmpty()) {
            Toast.makeText(getContext(), R.string.fragment_log_event_send_event_toast_error_custom_event, Toast.LENGTH_SHORT).show();
            return;
        }

        int childCount = llCustomValues.getChildCount();
        if (childCount > 0) {
            customParams = new HashMap<String, String>();
            for (int i = 0; i < childCount; i++) {
                if (llCustomValues.getChildAt(i) instanceof KeyValueView) {
                    KeyValueView childAt = (KeyValueView) llCustomValues.getChildAt(i);

                    String edtField1Input = childAt.getEdtField1Input();
                    String edtField2Input = childAt.getEdtField2Input();
                    customParams.put(edtField1Input,
                            edtField2Input);
                }
            }
        }


        IOLEvent event = EventHelper.getIOLEventFromString(eventName,
                kvvOptionalParameter.getEdtField1Input(),
                kvvOptionalParameter.getEdtField2Input(),
                customParams);
        if (event != null) {
            IOLSession.getSessionForType(App.getCurrentSessionType()).logEvent(event);
            Toast.makeText(getContext(), R.string.fragment_log_event_send_event_toast, Toast.LENGTH_SHORT).show();
            //clearViews();
            Static.hideKeyboard(getActivity());
        }
    }


}
