package com.infonline.sample.helper;

import android.util.Log;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import de.infonline.lib.IOLAdvertisementEvent;
import de.infonline.lib.IOLAudioEvent;
import de.infonline.lib.IOLBackgroundTaskEvent;
import de.infonline.lib.IOLCustomEvent;
import de.infonline.lib.IOLDataEvent;
import de.infonline.lib.IOLDeviceOrientationEvent;
import de.infonline.lib.IOLDocumentEvent;
import de.infonline.lib.IOLDownloadEvent;
import de.infonline.lib.IOLEvent;
import de.infonline.lib.IOLGameEvent;
import de.infonline.lib.IOLGestureEvent;
import de.infonline.lib.IOLHardwareButtonEvent;
import de.infonline.lib.IOLIAPEvent;
import de.infonline.lib.IOLLoginEvent;
import de.infonline.lib.IOLOpenAppEvent;
import de.infonline.lib.IOLPushEvent;
import de.infonline.lib.IOLUploadEvent;
import de.infonline.lib.IOLVideoEvent;
import de.infonline.lib.IOLViewEvent;

/**
 * Created by Lars Heinze on 20.11.17.
 * Copyright © 2017 RockAByte GmbH. All rights reserved.
 */

public class EventHelper {

    public static final List<String> publicEventList = new ArrayList<String>() {
        {
            add(IOLAdvertisementEvent.eventIdentifier);
            add(IOLAudioEvent.eventIdentifier);
            add(IOLBackgroundTaskEvent.eventIdentifier);
            add(IOLCustomEvent.eventIdentifier);
            add(IOLDataEvent.eventIdentifier);
            add(IOLDeviceOrientationEvent.eventIdentifier);
            add(IOLDocumentEvent.eventIdentifier);
            add(IOLDownloadEvent.eventIdentifier);
            add(IOLGameEvent.eventIdentifier);
            add(IOLGestureEvent.eventIdentifier);
            add(IOLHardwareButtonEvent.eventIdentifier);
            add(IOLIAPEvent.eventIdentifier);
            add(IOLLoginEvent.eventIdentifier);
            add(IOLOpenAppEvent.eventIdentifier);
            add(IOLPushEvent.eventIdentifier);
            add(IOLUploadEvent.eventIdentifier);
            add(IOLVideoEvent.eventIdentifier);
            add(IOLViewEvent.eventIdentifier);
        }
    };

    public static IOLEvent getIOLEventFromString(String eventname, String category, String comment, Map<String, String> customParams) {

        String[] eventSplit = eventname.split("\\.", 2);
        String eventIdentifier = eventSplit[0];
        String eventState = eventSplit[1];

        if (eventIdentifier.equals(IOLAdvertisementEvent.eventIdentifier)) {
            for (IOLAdvertisementEvent.IOLAdvertisementEventType type : IOLAdvertisementEvent.IOLAdvertisementEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLAdvertisementEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLAudioEvent.eventIdentifier)) {
            for (IOLAudioEvent.IOLAudioEventType type : IOLAudioEvent.IOLAudioEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLAudioEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLBackgroundTaskEvent.eventIdentifier)) {
            for (IOLBackgroundTaskEvent.IOLBackgroundTaskEventType type : IOLBackgroundTaskEvent.IOLBackgroundTaskEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLBackgroundTaskEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLDataEvent.eventIdentifier)) {
            for (IOLDataEvent.IOLDataEventType type : IOLDataEvent.IOLDataEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLDataEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLDeviceOrientationEvent.eventIdentifier)) {
            for (IOLDeviceOrientationEvent.IOLDeviceOrientationEventType type : IOLDeviceOrientationEvent.IOLDeviceOrientationEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLDeviceOrientationEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLDocumentEvent.eventIdentifier)) {
            for (IOLDocumentEvent.IOLDocumentEventType type : IOLDocumentEvent.IOLDocumentEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLDocumentEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLDownloadEvent.eventIdentifier)) {
            for (IOLDownloadEvent.IOLDownloadEventType type : IOLDownloadEvent.IOLDownloadEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLDownloadEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLGameEvent.eventIdentifier)) {
            for (IOLGameEvent.IOLGameEventType type : IOLGameEvent.IOLGameEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLGameEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLGestureEvent.eventIdentifier)) {
            for (IOLGestureEvent.IOLGestureEventType type : IOLGestureEvent.IOLGestureEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLGestureEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLHardwareButtonEvent.eventIdentifier)) {
            for (IOLHardwareButtonEvent.IOLHardwareButtonEventType type : IOLHardwareButtonEvent.IOLHardwareButtonEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLHardwareButtonEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLIAPEvent.eventIdentifier)) {
            for (IOLIAPEvent.IOLIAPEventType type : IOLIAPEvent.IOLIAPEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLIAPEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLLoginEvent.eventIdentifier)) {
            for (IOLLoginEvent.IOLLoginEventType type : IOLLoginEvent.IOLLoginEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLLoginEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLOpenAppEvent.eventIdentifier)) {
            for (IOLOpenAppEvent.IOLOpenAppEventType type : IOLOpenAppEvent.IOLOpenAppEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLOpenAppEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLPushEvent.eventIdentifier)) {
            for (IOLPushEvent.IOLPushEventType type : IOLPushEvent.IOLPushEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLPushEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLUploadEvent.eventIdentifier)) {
            for (IOLUploadEvent.IOLUploadEventType type : IOLUploadEvent.IOLUploadEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLUploadEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLViewEvent.eventIdentifier)) {
            for (IOLViewEvent.IOLViewEventType type : IOLViewEvent.IOLViewEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLViewEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLVideoEvent.eventIdentifier)) {
            for (IOLVideoEvent.IOLVideoEventType type : IOLVideoEvent.IOLVideoEventType.values()) {
                if (type.getState().equalsIgnoreCase(eventState)) {
                    return new IOLVideoEvent(type, category, comment, customParams);
                }
            }
        } else if (eventIdentifier.equals(IOLCustomEvent.eventIdentifier)) {
            return new IOLCustomEvent(eventState, category, comment, customParams);
        } else {
            Log.e("EventHelper", "unknown identifier " + eventIdentifier);
        }
        Log.e("EventHelper", "unknown state for identifier: " + eventname);
        return null;
    }

    public static boolean isPublicEvent(String eventName) {

        for (String identifier :
                publicEventList) {
            if (identifier.equals(eventName)) {
                return true;
            }
        }
        return false;
    }
}
