package com.infonline.sample.widgets;

import android.content.Context;
import android.support.annotation.Nullable;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.infonline.sample.R;

/**
 * Created by Dipl.-Ing. Mike Sebastian Drozd on 16.12.2017.
 * Copyright © 2017 RockAByte GmbH. All rights reserved.
 */

public class KeyValueView extends LinearLayout {

    private TextView tvTitle;
    private TextView tvField1;
    private EditText edtField1;
    private TextView tvField2;
    private EditText edtField2;

    public KeyValueView(Context context) {
        super(context);
        init(context);
    }


    public KeyValueView(Context context, @Nullable AttributeSet attrs) {
        super(context, attrs);
        init(context);
    }

    public KeyValueView(Context context, KeyValueViewModel keyValueViewModel) {
        super(context);
        init(context);
        setUpView(keyValueViewModel);
    }

    public void setUpView(KeyValueViewModel keyValueViewModel) {
        setTitle(keyValueViewModel.getTvTitle());
        setTvField1(keyValueViewModel.getTvField1());
        setEdtField1(keyValueViewModel.getEdtField1());
        setTvField2(keyValueViewModel.getTvField2());
        setEdtField2(keyValueViewModel.getEdtField2());
    }

    private void init(Context context) {
        LayoutInflater.from(context).inflate(R.layout.item_custom_parameter, this);

        tvTitle = findViewById(R.id.item_custom_tv_title);

        tvField1 = findViewById(R.id.item_custom_tv_field_1_title);
        edtField1 = findViewById(R.id.item_custom_edt_field_1_value);

        tvField2 = findViewById(R.id.item_custom_tv_field_2_title);
        edtField2 = findViewById(R.id.item_custom_edt_field_2_value);

    }

    public void setTitle(String string) {
        tvTitle.setText(string);
    }

    public void setTvField1(String string) {
        tvField1.setText(string);
    }

    public void setEdtField1(String string) {
        edtField1.setHint(string);
    }

    public void setTvField2(String string) {
        tvField2.setText(string);
    }

    public void setEdtField2(String string) {
        edtField2.setHint(string);
    }


    public String getEdtField1Input() {
        return edtField1.getText().toString();
    }

    public String getEdtField2Input() {
        return edtField2.getText().toString();
    }

    public void clearInput() {
        edtField1.setText("");
        edtField2.setText("");
    }

    public static class KeyValueViewModel {
        String tvTitle;
        String tvField1;
        String edtField1;
        String tvField2;
        String edtField2;

        public KeyValueViewModel(String tvTitle, String tvField1, String edtField1, String tvField2, String edtField2) {
            this.tvTitle = tvTitle;
            this.tvField1 = tvField1;
            this.edtField1 = edtField1;
            this.tvField2 = tvField2;
            this.edtField2 = edtField2;
        }

        public void setTvTitle(String tvTitle) {
            this.tvTitle = tvTitle;
        }

        public void setTvField1(String tvField1) {
            this.tvField1 = tvField1;
        }

        public void setEdtField1(String edtField1) {
            this.edtField1 = edtField1;
        }

        public void setTvField2(String tvField2) {
            this.tvField2 = tvField2;
        }

        public void setEdtField2(String edtField2) {
            this.edtField2 = edtField2;
        }

        String getTvTitle() {
            return tvTitle;
        }

        String getTvField1() {
            return tvField1;
        }

        String getEdtField1() {
            return edtField1;
        }

        String getTvField2() {
            return tvField2;
        }

        String getEdtField2() {
            return edtField2;
        }
    }
}
